package com.jiuqi.dna.ide.designer.toolkit;

import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;

/* loaded from: com_jiuqi_dna_ide_designer_toolkit.jar:com/jiuqi/dna/ide/designer/toolkit/ToolkitManager.class */
public class ToolkitManager {
    private static RootCompositeDescriptor uiRootCompositeDescriptor;
    private static ArrayList<Class<?>> loadedClasses = new ArrayList<>();
    private static HashMap<String, ToolkitElement> uiToolkitElements = new HashMap<>();
    private static HashMap<String, ToolkitElement> wfToolkitElements = new HashMap<>();
    private static HashMap<String, LayoutDescriptor> layoutDescriptors = new HashMap<>();

    public static void loadToolkitElements() {
        IExtensionRegistry er = Platform.getExtensionRegistry();
        IExtensionPoint ep = er.getExtensionPoint(ElementConstants.ExtensionPoint_NameSpace, ElementConstants.ExtensionPoint_Name);
        if (ep == null) {
            System.err.println("扩展点没有找到！");
            return;
        }
        IExtension[] extensions = ep.getExtensions();
        if (extensions == null) {
            System.out.println("没有任何注册控件！");
            return;
        }
        for (IExtension extension : extensions) {
            IConfigurationElement[] configs = extension.getConfigurationElements();
            if (configs != null) {
                for (IConfigurationElement config : configs) {
                    try {
                        Object obj = config.createExecutableExtension(ElementConstants.ExtensionPoint_ClassPath);
                        addElements(obj.getClass());
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }

    public static void addElements(Class<?> clazz) {
        if (clazz == null) {
            throw new NullPointerException("参数clazz不能为NULL！");
        }
        if (loadedClasses.contains(clazz)) {
            return;
        }
        loadedClasses.add(clazz);
        InputStream in = clazz.getResourceAsStream(ElementConstants.WidgetPackage_DescriptionFile);
        if (in == null) {
            System.err.println("无法找到描述文件！");
            return;
        }
        SAXBuilder builder = new SAXBuilder();
        try {
            Document doc = builder.build(in);
            Element root = doc.getRootElement();
            for (Element element : root.getChildren("Element")) {
                ToolkitElement toolkitElement = parseElement(element);
                String smallIconUrl = toolkitElement.getSmallIconUrl();
                if (smallIconUrl != null) {
                    ImageDescriptor imageDescriptor = ImageDescriptor.createFromFile(clazz, smallIconUrl);
                    toolkitElement.setSmallIcon(imageDescriptor);
                }
                String largeIconUrl = toolkitElement.getLargeIconUrl();
                if (largeIconUrl != null) {
                    ImageDescriptor imageDescriptor2 = ImageDescriptor.createFromFile(clazz, largeIconUrl);
                    toolkitElement.setLargeIcon(imageDescriptor2);
                }
                String imageUrl = toolkitElement.getImageUrl();
                if (imageUrl != null) {
                    ImageDescriptor imageDescriptor3 = ImageDescriptor.createFromFile(clazz, imageUrl);
                    toolkitElement.setImage(imageDescriptor3.createImage());
                }
                addToolkitElement(toolkitElement);
            }
            for (Element layout : root.getChildren("Layout")) {
                LayoutDescriptor layoutDescriptor = parseLayout(layout);
                addLayoutDescriptor(layoutDescriptor);
            }
            Iterator<?> iter = root.getChildren("RootComposite").iterator();
            if (iter.hasNext()) {
                Element rootComposite = (Element) iter.next();
                uiRootCompositeDescriptor = parseRootComposite(rootComposite);
            }
        } catch (IOException e) {
            e.printStackTrace();
        } catch (JDOMException e2) {
            e2.printStackTrace();
        }
    }

    private static ToolkitElement parseElement(Element element) {
        ToolkitElement toolkitElement = new ToolkitElement();
        toolkitElement.setId(element.getAttributeValue(ElementConstants.PropertyId));
        toolkitElement.setName(element.getAttributeValue("name"));
        toolkitElement.setType(element.getAttributeValue("type"));
        toolkitElement.setCatalog(element.getAttributeValue("catalog"));
        toolkitElement.setGroup(element.getAttributeValue("group"));
        toolkitElement.setVisible(!"0".equals(element.getAttributeValue(ElementConstants.PropertyVisible)));
        toolkitElement.setContainable("1".equals(element.getAttributeValue("isComposite")));
        toolkitElement.setSmallIconUrl(element.getAttributeValue("smallIconUrl"));
        toolkitElement.setLargeIconUrl(element.getAttributeValue("largeIconUrl"));
        toolkitElement.setImageUrl(element.getAttributeValue("imageUrl"));
        Element description = element.getChild("Description");
        if (description != null) {
            toolkitElement.setDescription(description.getText());
        }
        Element properties = element.getChild("Properties");
        if (properties != null) {
            for (Element property : properties.getChildren("Property")) {
                PropertyDescriptor descriptor = parseProperty(property);
                if (descriptor != null) {
                    toolkitElement.getPropertyDescriptors().add(descriptor);
                }
            }
        }
        Element customEditor = element.getChild("CustomEditor");
        if (customEditor != null) {
            toolkitElement.setCustomEditorClassPath(customEditor.getAttributeValue(ElementConstants.ExtensionPoint_ClassPath));
        }
        Element styles = element.getChild("Styles");
        if (styles != null) {
            for (Element style : styles.getChildren("Style")) {
                String styleName = style.getAttributeValue("name");
                if (styleName != null) {
                    toolkitElement.getStyles().add(styleName);
                }
            }
        }
        Element events = element.getChild("Events");
        if (events != null) {
            for (Element event : events.getChildren("Event")) {
                String eventName = event.getAttributeValue("name");
                if (eventName != null) {
                    toolkitElement.getEvents().add(eventName);
                }
            }
        }
        return toolkitElement;
    }

    private static PropertyDescriptor parseProperty(Element property) {
        PropertyDescriptor propertyDescriptor = new PropertyDescriptor();
        propertyDescriptor.setPropertyName(property.getAttributeValue("name"));
        propertyDescriptor.setType(property.getAttributeValue("type"));
        propertyDescriptor.setDefaultValue(property.getAttributeValue("defaultValue"));
        Element editor = property.getChild("Editor");
        EditorDescriptor editorDescriptor = new EditorDescriptor();
        if (editor != null) {
            String type = editor.getAttributeValue("type");
            if (type != null) {
                editorDescriptor.setType(Integer.valueOf(type).intValue());
            }
            String readOnly = editor.getAttributeValue("readOnly");
            if (readOnly != null) {
                editorDescriptor.setReadOnly("1".equals(readOnly));
            }
            Element list = editor.getChild("List");
            if (list != null) {
                for (Element value : list.getChildren("Value")) {
                    editorDescriptor.addListValue(value.getText());
                }
            }
            EditorButtonDescriptor editorButtonDescriptor = new EditorButtonDescriptor();
            Element button = editor.getChild("Button");
            if (button != null) {
                String action = button.getAttributeValue("action");
                if (action != null) {
                    editorButtonDescriptor.setAction(Integer.valueOf(action).intValue());
                }
                String extensions = button.getAttributeValue("extensions");
                if (extensions != null) {
                    editorButtonDescriptor.setExtensionsString(extensions);
                }
            }
            editorDescriptor.setEditorButtonDescriptor(editorButtonDescriptor);
        }
        propertyDescriptor.setEditorDescriptor(editorDescriptor);
        return propertyDescriptor;
    }

    private static LayoutDescriptor parseLayout(Element layout) {
        LayoutDescriptor layoutDescriptor = new LayoutDescriptor();
        layoutDescriptor.setName(layout.getAttributeValue("name"));
        Element properties = layout.getChild("Properties");
        if (properties != null) {
            for (Element property : properties.getChildren("Property")) {
                PropertyDescriptor descriptor = parseProperty(property);
                if (descriptor != null) {
                    layoutDescriptor.getPropertyDescriptors().add(descriptor);
                }
            }
        }
        return layoutDescriptor;
    }

    private static RootCompositeDescriptor parseRootComposite(Element rootComposite) {
        RootCompositeDescriptor rootCompositeDescriptor = new RootCompositeDescriptor();
        String id = rootComposite.getAttributeValue(ElementConstants.PropertyId);
        ToolkitElement compositeElement = getElement(id);
        if (compositeElement == null) {
            return null;
        }
        rootCompositeDescriptor.setCompositeElement(compositeElement);
        Element properties = rootComposite.getChild("Properties");
        if (properties != null) {
            for (Element property : properties.getChildren("Property")) {
                PropertyDescriptor descriptor = parseProperty(property);
                if (descriptor != null) {
                    rootCompositeDescriptor.getPropertyDescriptors().add(descriptor);
                }
            }
        }
        return rootCompositeDescriptor;
    }

    public static void addToolkitElement(ToolkitElement element) {
        if (ElementConstants.ElementType_UI.equalsIgnoreCase(element.getType())) {
            uiToolkitElements.put(element.getId(), element);
        }
        if (ElementConstants.ElementType_Workflow.equalsIgnoreCase(element.getType())) {
            wfToolkitElements.put(element.getId(), element);
        }
    }

    public static void removeToolkitElement(ToolkitElement element) {
        if (ElementConstants.ElementType_UI.equalsIgnoreCase(element.getType())) {
            uiToolkitElements.remove(element.getId());
        }
        if (ElementConstants.ElementType_Workflow.equalsIgnoreCase(element.getType())) {
            wfToolkitElements.remove(element.getId());
        }
    }

    public static ArrayList<ToolkitElement> getUIElements() {
        ArrayList<ToolkitElement> elements = new ArrayList<>(uiToolkitElements.values());
        Collections.sort(elements);
        return elements;
    }

    public static ArrayList<ToolkitElement> getWorkflowElements() {
        ArrayList<ToolkitElement> elements = new ArrayList<>(wfToolkitElements.values());
        Collections.sort(elements);
        return elements;
    }

    public static ToolkitElement getElement(String id) {
        if (id == null) {
            return null;
        }
        ToolkitElement element = uiToolkitElements.get(id);
        if (element != null) {
            return element;
        }
        return wfToolkitElements.get(id);
    }

    public static void addLayoutDescriptor(LayoutDescriptor layoutDescriptor) {
        layoutDescriptors.put(layoutDescriptor.getName(), layoutDescriptor);
    }

    public static ArrayList<LayoutDescriptor> getLayoutDescriptors() {
        ArrayList<LayoutDescriptor> layouts = new ArrayList<>(layoutDescriptors.values());
        Collections.sort(layouts);
        return layouts;
    }

    public static LayoutDescriptor getLayoutDescriptor(String name) {
        if (name == null) {
            return null;
        }
        LayoutDescriptor layout = layoutDescriptors.get(name);
        return layout;
    }

    public static void removeLayoutDescriptor(LayoutDescriptor layoutDescriptor) {
        layoutDescriptors.remove(layoutDescriptor.getName());
    }

    public static RootCompositeDescriptor getUiRootCompositeDescriptor() {
        return uiRootCompositeDescriptor;
    }

    public static ArrayList<String> getUIElementCatalogs() {
        return getElementCatalogs(getUIElements());
    }

    public static ArrayList<String> getWorkflowElementCatalogs() {
        return getElementCatalogs(getWorkflowElements());
    }

    private static ArrayList<String> getElementCatalogs(ArrayList<ToolkitElement> elements) {
        HashSet<String> catalogSet = new HashSet<>();
        Iterator<ToolkitElement> it = elements.iterator();
        while (it.hasNext()) {
            ToolkitElement element = it.next();
            catalogSet.add(element.getCatalog());
        }
        ArrayList<String> catalogs = new ArrayList<>(catalogSet);
        Collections.sort(catalogs);
        return catalogs;
    }

    public static ArrayList<ToolkitElement> getUIElementsByCatalog(String catalog) {
        return getElementsByCatalog(getUIElements(), catalog);
    }

    public static ArrayList<ToolkitElement> getWorkflowElementsByCatalog(String catalog) {
        return getElementsByCatalog(getWorkflowElements(), catalog);
    }

    private static ArrayList<ToolkitElement> getElementsByCatalog(ArrayList<ToolkitElement> elements, String catalog) {
        ArrayList<ToolkitElement> catalogElements = new ArrayList<>();
        Iterator<ToolkitElement> it = elements.iterator();
        while (it.hasNext()) {
            ToolkitElement element = it.next();
            if (element.getCatalog().equals(catalog)) {
                catalogElements.add(element);
            }
        }
        Collections.sort(catalogElements);
        return catalogElements;
    }

    public static ArrayList<String> getUIElementGroupsByCatalog(String catalog) {
        return getElementGroups(getUIElementsByCatalog(catalog));
    }

    public static ArrayList<String> getWorkflowElementGroupsByCatalog(String catalog) {
        return getElementGroups(getWorkflowElementsByCatalog(catalog));
    }

    private static ArrayList<String> getElementGroups(ArrayList<ToolkitElement> elements) {
        HashSet<String> groupSet = new HashSet<>();
        Iterator<ToolkitElement> it = elements.iterator();
        while (it.hasNext()) {
            ToolkitElement element = it.next();
            groupSet.add(element.getGroup());
        }
        ArrayList<String> groups = new ArrayList<>(groupSet);
        Collections.sort(groups);
        return groups;
    }

    public static ArrayList<ToolkitElement> getUIElementsByCatalogAndGroup(String catalog, String group) {
        return getElementsByGroup(getUIElementsByCatalog(catalog), group);
    }

    public static ArrayList<ToolkitElement> getWorkflowElementsByCatalogAndGroup(String catalog, String group) {
        return getElementsByGroup(getWorkflowElementsByCatalog(catalog), group);
    }

    private static ArrayList<ToolkitElement> getElementsByGroup(ArrayList<ToolkitElement> elements, String group) {
        ArrayList<ToolkitElement> catalogElements = new ArrayList<>();
        Iterator<ToolkitElement> it = elements.iterator();
        while (it.hasNext()) {
            ToolkitElement element = it.next();
            if (element.getGroup().equals(group)) {
                catalogElements.add(element);
            }
        }
        Collections.sort(catalogElements);
        return catalogElements;
    }
}
